import enum
import sys

from PyQt5.QtCore import Q_ENUM, pyqtProperty
from PyQt5.QtWidgets import QApplication, QProgressBar


class ProgressBar(QProgressBar):
    class Status(enum.IntEnum):
        success = 0
        error = 1
    Q_ENUM(Status)

    def __init__(self):
        self._status = ProgressBar.Status.success
        super().__init__()
        self.startTimer(2000)

    def timerEvent(self, _):
        next_status = {
            ProgressBar.Status.error: ProgressBar.Status.success,
            ProgressBar.Status.success: ProgressBar.Status.error,
        }
        self.status = next_status[self._status]
        self.style().unpolish(progress_bar)
        self.style().polish(progress_bar)

    @pyqtProperty(Status)
    def status(self):
        return self._status

    @status.setter
    def status(self, status):
        self._status = status


app = QApplication([])

progress_bar = ProgressBar()
progress_bar.setValue(50)
progress_bar.setStyleSheet("""
ProgressBar {
    background-color: darkgrey;
}

ProgressBar::chunk {
    background-color: yellow;
}

ProgressBar[status="0"]::chunk {
    background-color: green;
}

ProgressBar[status="1"]::chunk {
    background-color: red;
}
""")
progress_bar.show()

sys.exit(app.exec())
